import getBasePlacement from './getBasePlacement';
import getVariationPlacement from './getVariationPlacement';
import getMainAxisFromPlacement from './getMainAxisFromPlacement';
import getAltAxis from './getAltAxis';
import getAltLen from './getAltLen';
import { top, right, bottom, left, start, end } from '../enums';
export default (function (_ref) {
  var reference = _ref.reference,
      element = _ref.element,
      strategy = _ref.strategy,
      placement = _ref.placement,
      scroll = _ref.scroll;
  var basePlacement = placement ? getBasePlacement(placement) : null;
  var variationPlacement = placement ? getVariationPlacement(placement) : null;
  var scrollTop = scroll.scrollTop,
      scrollLeft = scroll.scrollLeft;
  var offsets;

  switch (basePlacement) {
    case top:
      offsets = {
        x: reference.x + reference.width / 2 - element.width / 2 - scrollLeft,
        y: reference.y - element.height - scrollTop
      };
      break;

    case bottom:
      offsets = {
        x: reference.x + reference.width / 2 - element.width / 2 - scrollLeft,
        y: reference.y + reference.height - scrollTop
      };
      break;

    case right:
      offsets = {
        x: reference.x + reference.width - scrollLeft,
        y: reference.y + reference.height / 2 - element.height / 2 - scrollTop
      };
      break;

    case left:
      offsets = {
        x: reference.x - element.width - scrollLeft,
        y: reference.y + reference.height / 2 - element.height / 2 - scrollTop
      };
      break;

    default:
      offsets = {
        x: reference.x - scrollLeft,
        y: reference.y - scrollTop
      };
  }

  var mainAxis = placement ? getMainAxisFromPlacement(placement) : null;
  var altAxis = mainAxis ? getAltAxis(mainAxis) : null;
  var len = altAxis === 'x' ? 'width' : 'height';
  var axis = [right, left].includes(basePlacement) ? mainAxis : altAxis;

  if (axis != null) {
    switch (variationPlacement) {
      case start:
        offsets[axis] -= element[len] / 2;
        break;

      case end:
        offsets[axis] += element[len] / 2;
        break;

      default:
    }
  }

  return offsets;
});